@@ -186,4 +186,4 @@ def do_slide(
         action = ActionChains(driver)  # 新建ActionChains对象防止累加位移
     time.sleep(0.5)
     ActionChains(driver).release().perform()
-    return True
+    return driver
